ggforestplotR-package: ggforestplotR: Forest plots from model coefficients with...

ggforestplotR-packageR Documentation

ggforestplotR: Forest plots from model coefficients with ggplot2

Description

Transform model coefficients into flexible forest plots using ggplot2. Provides helpers to standardize coefficient data from a range of modelling workflows and render publication-ready coefficient plots with a consistent interface.

Author(s)

Maintainer: Carson Richardson carson.richardson@outlook.com [copyright holder]

Authors:

See Also

Useful links:


ggforestplotR documentation built on June 5, 2026, 5:07 p.m.