Returns the semantic and provenance metadata attached to a forest_data
object. Plotting behavior is determined by this metadata rather than by the
class of the original fitted model.
Returns the semantic and provenance metadata attached to a forest_data
object. Plotting behavior is determined by this metadata rather than by the
class of the original fitted model.